==> codecs-antix_16.16.tar.xz: codecs-antix/translations/codecs_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja" version="2.1">
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="55"/>
        <source>You must run this program as root.</source>
        <translation>このプログラムは root で実行する必要があります。</translation>
    </message>
</context>
<context>
    <name>codecs</name>
    <message>
        <location filename="codecs.ui" line="14"/>
        <location filename="ui_codecs.h" line="173"/>
        <source>Codecs Installer</source>
        <translation>コーデックインストーラ</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="33"/>
        <location filename="ui_codecs.h" line="174"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;このアプリケーションによって、先進された映像・音楽機能を実現する制限されたコーデックをインストールすることができます。&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;ユーザーが条件を満たさなければならないように、若干配布制限が生じるかもしれません。&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;法令を引き受け、これらのコーデックをダウンロードしますか？&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="48"/>
        <location filename="ui_codecs.h" line="175"/>
        <source>Downloading codecs files</source>
        <translation>コーデックファイルのダウンロード中</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="102"/>
        <location filename="ui_codecs.h" line="178"/>
        <source>Cancel any changes then quit</source>
        <translation>変更をキャンセルして終了</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="105"/>
        <location filename="codecs.cpp" line="213"/>
        <location filename="ui_codecs.h" line="180"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="112"/>
        <location filename="ui_codecs.h" line="181"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="122"/>
        <location filename="ui_codecs.h" line="183"/>
        <source>Apply any changes then quit</source>
        <translation>変更を適用して終了</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="125"/>
        <location filename="ui_codecs.h" line="185"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="180"/>
        <location filename="ui_codecs.h" line="189"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="183"/>
        <location filename="ui_codecs.h" line="191"/>
        <source>About...</source>
        <translation>About...</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="190"/>
        <location filename="ui_codecs.h" line="192"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="219"/>
        <location filename="ui_codecs.h" line="194"/>
        <source>Display help </source>
        <translation>ヘルプ表示</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="222"/>
        <location filename="ui_codecs.h" line="196"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="229"/>
        <location filename="ui_codecs.h" line="197"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="114"/>
        <location filename="codecs.cpp" line="121"/>
        <location filename="codecs.cpp" line="129"/>
        <location filename="codecs.cpp" line="136"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;実行コマンド...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="117"/>
        <location filename="codecs.cpp" line="132"/>
        <location filename="codecs.cpp" line="138"/>
        <location filename="codecs.cpp" line="166"/>
        <location filename="codecs.cpp" line="192"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="118"/>
        <location filename="codecs.cpp" line="133"/>
        <source>Cannot connect to the download site</source>
        <translation>ダウンロードサイトに接続できません</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="124"/>
        <location filename="codecs.cpp" line="139"/>
        <source>Error downloading %1</source>
        <translation>ダウンロードエラー %1</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="143"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;ダウンロード完了&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="162"/>
        <source>Installing downloaded files</source>
        <translation>ダウンロードファイルをインストール中</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="167"/>
        <source>No downloaded *.debs files found.</source>
        <translation>ダウンロードした *.deb ファイルが見つかりません</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="174"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;インストール中...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="177"/>
        <source>Error installing %1</source>
        <translation>インストールエラー %1</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="185"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;インストール作業が完了しました&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="188"/>
        <source>Finished</source>
        <translation>完了</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="189"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>コーデックファイルのダウンロード・インストールが完了しました。</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="193"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>処理が完了しました。インストールでエラーが発生しています。</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="207"/>
        <source>About Codecs</source>
        <translation>Codecs について </translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="208"/>
        <source>Codecs</source>
        <translation>Codecs</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="208"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="210"/>
        <source>Simple codecs downloader</source>
        <translation>のシンプルなコーデックダウンローダー</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="211"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="212"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
</context>
</TS>

==> codecs-antix_16.23.tar.xz: codecs-antix/translations/codecs_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja" version="2.1">
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="53"/>
        <source>Unable to get exclusive lock</source>
        <translation>排他ロックを取得できません</translation>
    </message>
    <message>
        <location filename="main.cpp" line="54"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>別のパッケージ管理アプリケーション (Synaptic や apt-get) がすでに実行されています。まずそのアプリケーションを閉じてください</translation>
    </message>
    <message>
        <location filename="main.cpp" line="67"/>
        <source>You must run this program as root.</source>
        <translation>このプログラムは root で実行する必要があります。</translation>
    </message>
</context>
<context>
    <name>codecs</name>
    <message>
        <location filename="codecs.ui" line="14"/>
        <source>Codecs Installer</source>
        <translation>コーデックインストーラ</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;このアプリケーションによって、先進された映像・音楽機能を実現する制限されたコーデックをインストールすることができます。&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;ユーザーが条件を満たさなければならないように、若干配布制限が生じるかもしれません。&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;法令を引き受け、これらのコーデックをダウンロードしますか？&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>コーデックファイルのダウンロード中</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="94"/>
        <source>Cancel any changes then quit</source>
        <translation>変更をキャンセルして終了</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="97"/>
        <location filename="codecs.cpp" line="269"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="105"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="118"/>
        <source>Apply any changes then quit</source>
        <translation>変更を適用して終了</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="121"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="177"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="180"/>
        <source>About...</source>
        <translation>About...</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="188"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="217"/>
        <source>Display help </source>
        <translation>ヘルプ表示</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="220"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="228"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="110"/>
        <location filename="codecs.cpp" line="117"/>
        <location filename="codecs.cpp" line="125"/>
        <location filename="codecs.cpp" line="132"/>
        <location filename="codecs.cpp" line="140"/>
        <location filename="codecs.cpp" line="147"/>
        <location filename="codecs.cpp" line="156"/>
        <location filename="codecs.cpp" line="163"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;実行コマンド...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="113"/>
        <location filename="codecs.cpp" line="128"/>
        <location filename="codecs.cpp" line="134"/>
        <location filename="codecs.cpp" line="143"/>
        <location filename="codecs.cpp" line="149"/>
        <location filename="codecs.cpp" line="159"/>
        <location filename="codecs.cpp" line="165"/>
        <location filename="codecs.cpp" line="194"/>
        <location filename="codecs.cpp" line="246"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="114"/>
        <location filename="codecs.cpp" line="129"/>
        <location filename="codecs.cpp" line="144"/>
        <location filename="codecs.cpp" line="160"/>
        <source>Cannot connect to the download site</source>
        <translation>ダウンロードサイトに接続できません</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="120"/>
        <location filename="codecs.cpp" line="135"/>
        <location filename="codecs.cpp" line="150"/>
        <location filename="codecs.cpp" line="166"/>
        <source>Error downloading %1</source>
        <translation>ダウンロードエラー %1</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="171"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;ダウンロード完了&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="190"/>
        <source>Installing downloaded files</source>
        <translation>ダウンロードファイルをインストール中</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="195"/>
        <source>No downloaded *.debs files found.</source>
        <translation>ダウンロードした *.deb ファイルが見つかりません</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="211"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;インストール中...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="215"/>
        <source>Error installing %1</source>
        <translation>インストールエラー %1</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="239"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;インストール作業が完了しました&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="242"/>
        <source>Finished</source>
        <translation>完了</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="243"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>コーデックファイルのダウンロード・インストールが完了しました。</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="247"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>処理が完了しました。インストールでエラーが発生しています。</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="262"/>
        <source>About Codecs</source>
        <translation>Codecs について </translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="263"/>
        <source>Codecs</source>
        <translation>Codecs</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="263"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="265"/>
        <source>Simple codecs downloader for antiX Linux</source>
        <translation>antiX Linux のシンプルなコーデックダウンローダー</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="266"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="267"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="268"/>
        <source>Changelog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="codecs.cpp" line="284"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
</context>
</TS>
